#!/bin/sh
#
# Copyright 2010-present Facebook.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

# This script builds the API documentation from source-level comments.
# This script requires appledoc be installed: https://github.com/tomaz/appledoc

. ${BOLTS_SCRIPT:-$(dirname $0)}/common.sh

test -x "$APPLEDOC" || die 'Could not find appledoc in $PATH - run git clone git://github.com/tomaz/appledoc.git && appledoc/install-appledoc.sh'

# -----------------------------------------------------------------------------
# Build pre-requisites
#
if is_outermost_build; then
    . $BOLTS_SCRIPT/build_framework.sh -n
fi
progress_message Building Documentation.

# -----------------------------------------------------------------------------
# Build docs
#
test -d $BOLTS_BUILD \
  || mkdir -p $BOLTS_BUILD \
  || die "Could not create directory $BOLTS_BUILD"

cd $BOLTS_SRC

DOCSET="$BOLTS_BUILD"/"$BOLTS_DOCSET_NAME"

rm -rf $DOCSET

hash $APPLEDOC &>/dev/null
if [ "$?" -eq "0" ]; then
    APPLEDOC_DOCSET_NAME="Bolts"
    $APPLEDOC --project-name "$APPLEDOC_DOCSET_NAME" \
	--project-company "Parse Inc." \
	--company-id "com.parse" \
	--output "$DOCSET" \
	--preprocess-headerdoc \
	--docset-bundle-name "$APPLEDOC_DOCSET_NAME" \
	--docset-feed-name "$APPLEDOC_DOCSET_NAME" \
	--exit-threshold 2 \
	--no-install-docset \
	--search-undocumented-doc \
	--keep-undocumented-members \
	--keep-undocumented-objects \
	--explicit-crossref \
	$BOLTS_IOS_FRAMEWORK/Headers \
    || die 'appledoc execution failed'
else
    die "appledoc not installed, unable to build documentation"
fi

#TODO: If we add protocols, we should pull the fix from the FB iOS SDK.

# -----------------------------------------------------------------------------
# Done
#
common_success
